@@ -57,11 +57,10 @@
 
 #' @export
 #' @examples
-#' # Load example data from the package
+#' \donttest{
+#' # Example 1: Binary outcome data
 #' data(example_data)
-
-#' # Generate the forest plot and return effect estimates and proportion contributions
-
+#' 
 #' NMAforest(
 #'   data = example_data,
 #'   sm = "OR",
@@ -75,6 +74,25 @@
 #'   study_id = "id",
 #'   study_path = TRUE
 #' )
+#'
+#' # Example 2: Continuous outcome data
+#' data("parkinson", package = "pcnetmeta")
+#' 
+#' NMAforest(
+#'   data = parkinson,
+#'   sm = "MD",
+#'   reference = "1",
+#'   model = "random",
+#'   comparison = c("1", "3"),
+#'   study = "s.id",
+#'   treat = "t.id",
+#'   mean = "mean",
+#'   sd = "sd",
+#'   N = "n",
+#'   study_path = TRUE
+#' )
+#' }
+#' 
 #' @references
 #' Balduzzi, S., Rücker, G., Nikolakopoulou, A., Papakonstantinou, T., Salanti, G., Efthimiou, O., & Schwarzer, G. (2023).
 #' netmeta: An R Package for Network Meta-Analysis Using Frequentist Methods. *Journal of Statistical Software*, 106(2), 1–40.
@@ -95,7 +113,6 @@
 #'
 #' flow_contribution GitHub repository: https://github.com/esm-ispm-unibe-ch/flow_contribution
 
-
 # ------------------------------------------------------------------------------
 # This file includes code adapted from:
 #   streamstatistics2.R in the flow_contribution package
@@ -103,7 +120,6 @@
 #   License: GPL-2
 # ------------------------------------------------------------------------------
 
-
 NMAforest <- function(data,
                       sm,
                       reference,
@@ -121,6 +137,52 @@ NMAforest <- function(data,
   
   df <- data
   
+  # ---- Input validation: required columns (clear errors) ----
+  stop_if_missing <- function(cols, context = NULL) {
+    missing <- cols[!cols %in% names(df)]
+    if (length(missing) > 0) {
+      msg <- paste0(
+        "NMAforest(): Missing required column(s): ",
+        paste(missing, collapse = ", "),
+        if (!is.null(context)) paste0(" (", context, ").") else ".",
+        "\nAvailable columns: ", paste(names(df), collapse = ", "),
+        "\nTip: If your dataset uses different column names, specify them via ",
+        "`study=`, `treat=`, `event=`, `N=`, `mean=`, and `sd=`."
+      )
+      stop(msg, call. = FALSE)
+    }
+  }
+  
+  # Always required for all outcomes
+  stop_if_missing(c(study, treat, N), context = "required for all analyses")
+  
+  # Required depending on outcome type
+  if (sm %in% c("OR", "RR", "RD", "ASD")) {
+    stop_if_missing(c(event), context = "required for binary outcomes")
+  } else if (sm %in% c("MD", "SMD", "ROM")) {
+    stop_if_missing(c(mean, sd), context = "required for continuous outcomes")
+  } else {
+    stop("NMAforest(): Unsupported `sm`. Use one of OR, RR, RD, ASD, MD, SMD, ROM.", call. = FALSE)
+  }
+  # -----------------------------------------------------------
+  
+  # Early check: duplicate study-arm rows (one row per arm required)
+  dup_arm <- df %>%
+    dplyr::count(.data[[study]], .data[[treat]], name = "n_row") %>%
+    dplyr::filter(n_row > 1)
+  
+  if (nrow(dup_arm) > 0) {
+    stop(
+      sprintf(
+        "NMAforest(): Duplicate study-arm rows detected (same `%s` and `%s`). Please ensure one row per study arm.\nExample: study=%s, treat=%s.",
+        study, treat,
+        as.character(dup_arm[[study]][1]),
+        as.character(dup_arm[[treat]][1])
+      ),
+      call. = FALSE
+    )
+  }
+  
   # Generate id column if missing
   
   id_variants <- tolower(names(df))
@@ -135,6 +197,30 @@ NMAforest <- function(data,
     df <- left_join(df, study_map, by = study)
   }
   
+  # Early check: study <-> study_id mapping must be one-to-one
+  if (study_id %in% names(df)) {
+    
+    bad1 <- df %>%
+      dplyr::distinct(.data[[study]], .data[[study_id]]) %>%
+      dplyr::count(.data[[study]], name = "n_id") %>%
+      dplyr::filter(n_id > 1)
+    
+    bad2 <- df %>%
+      dplyr::distinct(.data[[study]], .data[[study_id]]) %>%
+      dplyr::count(.data[[study_id]], name = "n_study") %>%
+      dplyr::filter(n_study > 1)
+    
+    if (nrow(bad1) > 0 || nrow(bad2) > 0) {
+      stop(
+        sprintf(
+          "NMAforest(): Inconsistent mapping between `%s` and `%s`. Each study must map to exactly one study_id, and each study_id to exactly one study.",
+          study, study_id
+        ),
+        call. = FALSE
+      )
+    }
+  }
+  
   # Generate pairwise format
   if (sm %in% c("OR", "RR", "RD", "ASD")) {
     data_long <- eval(substitute(
@@ -174,7 +260,6 @@ NMAforest <- function(data,
     ))
   }
   
-  
   # netmeta and netsplit
   netmeta_result <- netmeta(
     TE = data_long$TE,
@@ -273,7 +358,7 @@ NMAforest <- function(data,
   ))
   
   # Indirect Paths
-  max_combos_per_path <- 30
+  max_combos_per_path <- 80
   edges <- data_long %>% select(treat1, treat2)
   g <- igraph::graph_from_data_frame(edges, directed = FALSE)
   all_paths <- igraph::all_simple_paths(g, from = comp1, to = comp2, cutoff = 4)
@@ -458,6 +543,7 @@ NMAforest <- function(data,
     }
   }
   
+  
   # NMA Effect
   if (comp1 %in% rownames(TE_matrix) && comp2 %in% colnames(TE_matrix)) {
     plot_data <- bind_rows(plot_data, tibble(
@@ -472,6 +558,7 @@ NMAforest <- function(data,
   plot_data <- plot_data %>%
     mutate(OrderIndex = nrow(.) - row_number() + 1)
   
+  
   tau <- netmeta_result$tau
   
   plot_data <- plot_data %>%
@@ -707,6 +794,9 @@ NMAforest <- function(data,
     setNames(rep(length(grouped_paths[[k]]), length(grouped_paths[[k]])), grouped_paths[[k]])
   }))
   
+  path_flow_map <- list()   # NEW: store flow for each path label
+  
+  
   indirect_bar_data <- tibble()
   
   for (path_label in names(indirect_path_info)) {
@@ -730,6 +820,9 @@ NMAforest <- function(data,
         if (all(path_nodes_clean %in% stream_nodes_clean) && all(stream_nodes_clean %in% path_nodes_clean)) {
           
           flow_val <- stream$flow/ path_group_lookup[[path_label]]
+          
+          path_flow_map[[path_label]] <- flow_val   # NEW
+          
           indirect_bar_data <- bind_rows(indirect_bar_data, tibble(
             xstart = cumulative_start_indirect,
             xend = cumulative_start_indirect + flow_val,
@@ -849,6 +942,101 @@ NMAforest <- function(data,
     }
   }
   
+  # ============================================================
+  # Overwrite "Overall Indirect Effect" using paths + Cov(y)
+  # ============================================================
+  
+  # --- 0) Build (Path label, flow) exactly as shown in the plot (label-by-label) ---
+  path_df <- plot_data %>%
+    dplyr::filter(grepl("^Path\\s+", Label)) %>%
+    dplyr::transmute(
+      Label,
+      OrderIndex,
+      flow = indirect_bar_data$Proportion[match(OrderIndex, indirect_bar_data$y)]
+    ) %>%
+    dplyr::filter(is.finite(flow) & flow > 0)
+  
+  path_labels <- path_df$Label
+  path_flows  <- path_df$flow
+  
+  if (length(path_labels) > 0) {
+    
+    # --- 1) normalize across indirect paths only (same as your prototype) ---
+    alpha <- path_flows / sum(path_flows)
+    
+    # --- 2) study-level contrasts (pairwise rows) ---
+    y_vec <- data_long$TE
+    
+    # --- 3) Cov(y_vec)
+    tau2 <- if (model == "random") as.numeric(netmeta_result$tau)^2 else 0
+    if (!is.finite(tau2)) tau2 <- 0
+    
+    V <- diag(data_long$seTE^2 + tau2, nrow = length(y_vec))
+    stopifnot(is.matrix(V), nrow(V) == length(y_vec), ncol(V) == length(y_vec))
+    
+    # --- helpers ---
+    parse_nodes <- function(lbl) {
+      s <- sub("^Path\\s*", "", lbl)
+      trimws(unlist(strsplit(s, "\u2192")))
+    }
+    
+    # Edge direct pooling coefficients as linear combo of y_vec
+    # (sign convention matches your external prototype)
+    edge_coef <- function(from, to) {
+      idx1 <- which(data_long$treat1 == from & data_long$treat2 == to)
+      idx2 <- which(data_long$treat1 == to   & data_long$treat2 == from)
+      idx  <- c(idx1, idx2)
+      
+      if (length(idx) == 0) stop(sprintf("No direct evidence for edge %s-%s", from, to))
+      
+      sgn <- c(rep(-1, length(idx1)), rep(+1, length(idx2)))
+      w   <- 1 / diag(V)[idx]
+      
+      a <- numeric(length(y_vec))
+      a[idx] <- (w * sgn) / sum(w)
+      a
+    }
+    
+    # Each path coefficient is the sum of its oriented edge coefficients
+    path_coef <- function(nodes) {
+      cvec <- numeric(length(y_vec))
+      for (i in seq_len(length(nodes) - 1)) {
+        cvec <- cvec + edge_coef(nodes[i], nodes[i + 1])
+      }
+      cvec
+    }
+    
+    # --- 4) Overall indirect = sum_k alpha_k * theta_k => coefficient vector c_overall ---
+    c_overall <- numeric(length(y_vec))
+    for (k in seq_along(path_labels)) {
+      nodes <- parse_nodes(path_labels[k])
+      c_overall <- c_overall + alpha[k] * path_coef(nodes)
+    }
+    
+    # --- 5) Estimate + SE + CI ---
+    theta_hat <- sum(c_overall * y_vec)
+    var_hat   <- as.numeric(t(c_overall) %*% V %*% c_overall)
+    se_hat    <- sqrt(var_hat)
+    
+    ci_low <- theta_hat - 1.96 * se_hat
+    ci_up  <- theta_hat + 1.96 * se_hat
+    
+    # --- 6) overwrite the "Overall Indirect Effect" row in plot_data ---
+    plot_data <- plot_data %>%
+      dplyr::mutate(
+        EffectSize = dplyr::if_else(Label == "Overall Indirect Effect", theta_hat, EffectSize),
+        LowerCI    = dplyr::if_else(Label == "Overall Indirect Effect", ci_low,    LowerCI),
+        UpperCI    = dplyr::if_else(Label == "Overall Indirect Effect", ci_up,     UpperCI)
+      )
+    
+    # IMPORTANT: recompute raw_se + weight after overwriting CI
+    plot_data <- plot_data %>%
+      dplyr::mutate(
+        raw_se = (UpperCI - LowerCI) / (2 * 1.96),
+        weight = ifelse(!is.na(raw_se), 1 / (raw_se^2), NA)
+      )
+  }
+  
   xstart_total <- if (length(cumulative_start) > 0) {
     min(cumulative_start)
   } else if (length(cumulative_end) > 0) {
@@ -916,7 +1104,6 @@ NMAforest <- function(data,
     }
   }
   
-  
   # Estimate the top y-value
   top_y <- max(plot_data$OrderIndex, na.rm = TRUE) + 1.5
   
@@ -941,6 +1128,24 @@ NMAforest <- function(data,
       )
     )
   
+  # Pretty x-axis label for effect measure
+  sm_axis_label <- function(sm) {
+    sm <- toupper(sm)
+    
+    switch(sm,
+           "OR"  = "Odds Ratio",
+           "RR"  = "Risk Ratio",
+           "RD"  = "Risk Difference",
+           "ASD" = "Arcsine Difference",
+           "MD"  = "Mean Difference",
+           "SMD" = "Standardized Mean Difference",
+           "ROM" = "Ratio of Means",
+           sm  # fallback: keep original if unknown
+    )
+  }
+  
+  x_lab <- sm_axis_label(sm)
+  
   # Construct ggplot
   plot_object <- ggplot(plot_data, aes(y = OrderIndex)) +
     annotate("rect",
@@ -989,7 +1194,7 @@ NMAforest <- function(data,
         "Forest Plot for Comparison", comp1, "&", comp2,
         "-", ifelse(model == "random", "Random Effects Model", "Fixed Effects Model")
       ),
-      x = sm,
+      x = x_lab,
       y = NULL,
       color = "Type"
     ) +
@@ -1044,7 +1249,8 @@ NMAforest <- function(data,
 }
 
 utils::globalVariables(c(
-  "treat1", "treat2", ".", "UpperCI", "LowerCI", "raw_se", "weight", "Label",
-  "OrderIndex", "EffectSize", "Type", "size_scaled", "xstart", "xend", "Proportion", "bar_prop"
+  "treat1", "treat2", ".", "UpperCI", "LowerCI", "raw_se", "weight", "Label",".data",
+  "n_row", "n_id", "n_study","flow","OrderIndex", "EffectSize", "Type", "size_scaled", 
+  "xstart", "xend", "Proportion", "bar_prop"
 ))
 
